-- Slovak chart of accounts
-- Peter Meszaros <peterm@insypo.sk>
-- Kompletn tov osnova platn v roku 2007
--
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('01','NEHMOTN INVESTIN MAJETOK','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('02','HMOTN INVESTIN MAJETOK ODPISOVAN','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('03','HMOTN INVEST. MAJETOK NEODPISOVAN','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('04','OBSTARANIE NEHMOTNCH A HM. INVESTCI','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('05','POSKYTNUT PREDDAVKY NA NEHM. IM A HIM','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('06','FINANN INVESTCIE','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('07','OPRVKY K NEHMOTNMU IM','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('08','OPRVKY K HMOTNMU IM','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('09','OPRAVN POLOKY K IM','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('11','MATERIL','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('12','ZSOBY VLASTNEJ VROBY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('13','TOVAR','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('19','OPRAVN POLOKY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('21','PENIAZE','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('22','TY V BANKCH','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('23','BEN BANKOV VERY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('24','IN KRTKODOB FINANN VPOMOCI','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('25','KRTKODOB FINANN MAJETOK','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('26','PREVODY MEDZI FINANNMI TAMI','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('29','OPRAVN POLOKY KU KRTKOD. FIN. MAJETKU','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('31','POHADVKY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('32','ZVZKY ','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('33','ZTOVANIE SO ZAMESTNANCAMI A INTITCIAMI','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('34','ZTOVANIE DAN A DOTCI','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('35','POHADVKY VOI SPOLONKOM A ZDRUENIU','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('36','ZVZKY VOI SPOLONKOM A ZDRUENIU','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('37','IN POHADVKY A ZVZKY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('38','PRECHODN TY AKTV A PASV','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('39','OPR.POL. K ZT. VZAHOM A VNTORN ZTOV.','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('41','ZKLADN IMANIE A KAPITLOV FONDY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('42','FONDY ZO ZISKU A PREVEDEN HOSP. VSLEDKY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('43','HOSPODRSKY VSLEDOK','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('45','REZERVY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('46','BANKOV VERY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('47','DLHODOB ZVZKY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('48','ODLOEN DA','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('49','INDIVIDULNY PODNIKATE','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('50','SPOTREBOVAN NKUPY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('51','SLUBY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('52','OSOBN NKLADY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('53','DANE A POPLATKY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('54','IN PREVDZKOV NKLADY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('55','ODPISY,REZERVY A OPR. POL. PREVDZKOVCH N.','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('56','FINANN NKLADY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('57','REZERVY A OPRAVN POLOKY FINANNCH N.','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('58','MIMORIADNE NKLADY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('59','DANE Z PRJMOV A PREVODOV TY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('60','TRBY ZA VLASTN VKONY A TOVAR','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('61','ZMENA STAVU VNTROPODNIKOVCH ZSOB','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('62','AKTIVCIA','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('64','IN PREVDZKOV VNOSY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('65','ZT. REZERV A OPR. POLOIEK PREVDZKOV. V.','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('66','FINANN VNOSY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('67','ZT. REZERV A OPRAVNCH POL. FINANNCH V.','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('68','MIMORIADNE VNOSY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('69','PREVODOV TY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('70','ZAIATON A KONEN ET','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('71','ET ZISKOV A STRT','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('80','VNTROPODNIKOV NKLADY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('90','VNTROPODNIKOV VNOSY','H','\N','\N','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('010000','Dlhodob nehmotn majetok','A','01','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('011000','Zriaovacie vdavky','A','01','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('012000','Aktivovan nklady na vvoj','A','01','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('013000','Softvr','A','01','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('014000','Oceniteln prva','A','01','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('015000','Goodwill','A','01','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('019000','Ostatn nehmotn investin majetok','A','01','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('020000','Dlhodob hmotn majetok - odpisovan','A','02','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('021000','Stavby','A','02','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('022000','Samostatne hnuteln veci','A','02','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('025000','Pestovatelsk celky trvalch porastov','A','02','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('026000','Zkladn stdo a itkov zvierat','A','02','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('029000','Ostatn dlhodob hmotn majetok','A','02','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('030000','Dlhodob hmotn majetok - neodpisovan','A','03','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('031000','Pozemky','A','03','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('032000','Umeleck diela a zbierky','A','03','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('040000','Obstaranie dlhodobho majetku','A','04','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('041000','Obstaranie dlhodobho nehmotnho majetku','A','04','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('042000','Obstaranie dlhodobho hmotnho majetku','A','04','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('043000','Obstaranie dlhodobho finannho majetku','A','04','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('050000','Poskytnut preddavky na dlhodob majetok','A','05','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('051000','Poskytnut preddavky na nehmot. majetok','A','05','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('052000','Poskytnut preddavky na hmotn  majetok','A','05','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('053000','Poskytnut preddavky na finan majetok','A','05','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('060000','Dlhodob finann majetok','A','06','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('061000','Podiel.cenn papiere a podiely v ovl.os.','A','06','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('062000','Podiel.cenn papiere a podiely s podstat','A','06','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('063000','Realizovaten cenn papiere a podiely','A','06','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('065000','Dlhov cenn papiere dran do splatnost','A','06','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('066000','Poziky utov.jednotke v konsolid.celku','A','06','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('067000','Ostatn piky','A','06','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('069000','Ostan dlhodob finann majetok','A','06','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('070000','Oprvky k dlhodobmu nehmotnmu majetku','A','07','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('071000','Oprvky k zriadovacm nkladom','A','07','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('072000','Oprvky k aktivovanm nkladom na vvoj','A','07','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('073000','Oprvky k softvru','A','07','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('074000','Oprvky k ocenitelnm prvam','A','07','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('075000','Oprvky ku goodwillu','A','07','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('079000','Oprvky k ostatnmu drob.nehmot.majetku','A','07','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('080000','Oprvky k dlhodobmu hmotnmu majetku','A','08','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('081000','Oprvky k stavbm','A','08','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('082000','Oprvky k samostatnm hnutelnm veciam','A','08','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('085000','Oprvky k pestovatelskm celkom a poras.','A','08','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('086000','Oprvky k zklad.stdu a itkovm zvier','A','08','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('089000','Oprvky k ostat.dlhodob.hmotnmu majetku','A','08','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('090000','Opravn poloky k dlhodobmu majetku','A','09','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('091000','Opravn poloka k dlhodob.nehmot.majetku','A','09','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('092000','Opravn poloka k dlhodob.hmot.majetku','A','09','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('093000','Opravn poloka k nedok.nehmot.majetku','A','09','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('094000','Opravn poloka k nedok.hmot.majetku','A','09','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('095000','Opravn poloka k poskytnutm preddavkom','A','09','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('096000','Opravn poloka k dlhodob.finan.majetku','A','09','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('097000','Opravn poloka k nadobudnutmu majetku','A','09','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('098000','Oprvky k opr.poloke k nadobud.majetku','A','09','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('110000','Materil','A','11','A','IC');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('111000','Obstaranie materilu','A','11','A','IC');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('111600','Nkup zvierat','A','11','A','IC');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('112000','Materil na sklade','A','11','A','IC');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('119000','Materil na ceste','A','11','A','IC');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('120000','Zsoby vlastnej vroby','A','12','A','IC');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('121000','Nedokonen vroba','A','12','A','IC');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('122000','Polotovary vlastnej vroby','A','12','A','IC');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('123000','Vrobky','A','12','A','IC');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('124000','Zvierat','A','12','A','IC');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('130000','Tovar','A','13','A','IC');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('131000','Obstaranie tovaru','A','13','A','IC');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('132000','Tovar na sklade a v predajniach','A','13','A','IC');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('139000','Tovar na ceste','A','13','A','IC');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('190000','Opravn poloky k zsobm','A','19','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('191000','Opravn poloka k materialu','A','19','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('192000','Opravn poloka k nedokonenej vrobe','A','19','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('193000','Opravn poloka k polotovarom vl.vyroby','A','19','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('194000','Opravn poloka k vrobkom','A','19','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('195000','Opravn poloka k zvieratm','A','19','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('196000','Opravn poloka k tovaru','A','19','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('210000','Peniaze','A','21','A','AR_paid:AP_paid');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('211000','Pokladnica','A','21','A','AR_paid:AP_paid');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('213000','Ceniny','A','21','A','AR_paid:AP_paid');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('220000','ty v bankch','A','22','A','AR_paid:AP_paid');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('221000','Bankov ty','A','22','A','AR_paid:AP_paid');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('230000','Ben bankov very','A','23','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('231000','Krtkodob bankov very','A','23','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('232000','Eskontn very','A','23','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('240000','In krtkodob finann vpomoci','A','24','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('241000','Emitovan krtkodob dlhopisy','A','24','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('249000','Ostatn krtkodob finann vypomoci','A','24','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('250000','Krtkodob finann majetok','A','25','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('251000','Majetkov cenn papiere na ochodovanie','A','25','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('252000','Vlastn akcie a vlastn obchodn podiely','A','25','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('253000','Dlhov cenn papiere na obchodovanie','A','25','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('255000','Vlastn dlhopisy','A','25','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('256000','Dlhov cenn papiere so splat.do 1 roka','A','25','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('257000','Ostatn realizovatene cenn papiere','A','25','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('260000','Prevody medzi finannmi tami','A','26','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('261000','Peniaze na ceste','A','26','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('290000','Opravn poloka ku krtkodob.finan.maj.','A','29','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('291000','Opravn poloka ku krtkodob.finan.maj.','A','29','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('311000','Odberatelia','A','31','A','AR');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('312000','Zmenky na inkaso','A','31','A','AR');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('313000','Pohladvky za eskontn cenn papiere','A','31','A','AR');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('314000','Poskytnut preddavky','A','31','A','AR');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('315000','Ostan pohladvky','A','31','A','AR');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('321000','Dodavatelia','A','32','L','AP');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('322000','Zmenky na hradu','A','32','L','AP');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('323000','Krtkodob rezervy','A','32','L','AP');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('324000','Prijat preddavky','A','32','L','AP');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('325000','Ostatn zvzky','A','32','L','AP');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('326000','Nevyfaktrovan dodvky','A','32','L','AP');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('331000','Zamestnanci','A','33','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('333000','Ostatn zvzky voi zamenstnancom','A','33','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('335000','Pohladvky voi zamestnancom','A','33','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('336000','Zutovanie s in.soc.zabezpeenia a zdr.','A','33','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('341000','Da z prjmov','A','34','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('342000','Ostan priame dane','A','34','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('343000','Da z pridanej hodnoty','A','34','L','IC_taxpart:IC_taxservice');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('343100','Vstupn da z pridanej hodnoty','A','34','L','AP_tax:IC_taxpart:IC_taxservice');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('343110','Vstupn da PH 10%','A','34','L','AP_tax:IC_taxpart:IC_taxservice');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('343120','Vstupn da PH 19%','A','34','L','AP_tax:IC_taxpart:IC_taxservice');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('343200','Vstupn da z pridanej hodnoty','A','34','L','AR_tax:IC_taxpart:IC_taxservice');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('343210','Vstupn da PH 10%','A','34','L','AR_tax:IC_taxpart:IC_taxservice');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('343220','Vstupn da PH 19%','A','34','L','AR_tax:IC_taxpart:IC_taxservice');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('343900','Ostatn zutovanie dane z prid. hodnoty','A','34','L','IC_taxpart:IC_taxservice');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('343910','Vstupn da PH na ceste 10%','A','34','A','IC_taxpart:IC_taxservice');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('343920','Vstupn DPH na ceste 19 %','A','34','A','IC_taxpart:IC_taxservice');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('345000','Ostane dane a poplatky','A','34','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('346000','Dotcie zo ttneho rozpotu','A','34','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('347000','Ostatn dotcie','A','34','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('351000','Pohladvky v rmci konsolidovanho celku','A','35','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('353000','Pohladvky za upsan vlastn imanie','A','35','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('354000','Pohl.voi spolonkom pri hrade straty','A','35','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('355000','Ostatn pohladvky voi spolonkom','A','35','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('358000','Pohladvky voi astnkom zdruenia','A','35','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('361000','Zvzky v rmci konsolidovanho celku','A','36','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('364000','Zvzky voi spolo. pri rozdel. zisku','A','36','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('365000','Ostatn zvzky voi spolonkom','A','36','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('366000','Zvz.voi spolonkom zo zvislej inn.','A','36','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('367000','Zvzky z upisanch nespl.cennch papier','A','36','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('368000','Zvzky voi uastnkom zdruenia','A','36','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('371000','Pohladvky z predaja podniku','A','37','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('372000','Zvzky z predaja podniku','A','37','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('373000','Pohladvky a zvzky z pevnch termin.op','A','37','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('374000','Pohladvky z prenjmu','A','37','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('375000','Pohladvky z emitovanch dlhopisov','A','37','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('376000','Nakupn opcie','A','37','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('377000','Predajn opcie','A','37','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('378000','In pohladvky','A','37','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('379000','In zvzky','A','37','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('381000','Nklady budcich obdob','A','38','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('382000','Komplexn nklady budcich obdob','A','38','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('383000','Vdavky budcich obdob','A','38','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('384000','Vnosy budcich obdob','A','38','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('385000','Prjmy budcich obdob','A','38','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('391000','Opravn poloka k pohladvkam','A','39','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('395000','Vntorn ztovanie','A','39','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('398000','Spojovac et pri zdruen','A','39','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('411000','Zkladn imanie','A','41','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('412000','Emisn io','A','41','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('413000','Ostatn kapitlov fondy','A','41','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('414000','Oceovacie rozdiely z precenenia majetku','A','41','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('415000','Oceovacie rozdiely z kapitlovch uas.','A','41','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('416000','Oce.rozdiely z precenenia pri splyn.roz','A','41','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('417000','Zkonn rezervn fond z kapitl.vkladov','A','41','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('418000','Nedeliteln fond z kapitlovch vkladov','A','41','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('419000','Zmeny zkladnho imania','A','41','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('421000','Zkonn rezervn fond','A','42','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('422000','Nedeliteln fond','A','42','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('423000','tatutrne fondy','A','42','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('427000','Ostatn fondy','A','42','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('428000','Nerozdelen zisk  minulch rokov','A','42','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('429000','Neuhraden strata minulch rokov','A','42','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('431000','Hospodrsky vsledok v schvaovac.konan','A','43','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('451000','Rezervy zkonn','A','45','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('459000','Ostatn rezervy','A','45','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('461000','Bankov very','A','46','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('471000','Dlhodob zvzky v rmci konsolid.celku','A','47','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('472000','Zvzky zo socialnho fondu','A','47','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('473000','Emitovan dlhopisy','A','47','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('474000','Zvzky z prenjmu','A','47','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('475000','Dlhodob prijat preddavky','A','47','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('476000','Dlhodob nevyfakturovan dodvky','A','47','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('478000','Dlhodob zmenky na hradu','A','47','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('479000','Ostatn dlhodob zvzky','A','47','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('481000','Odloen daov zvzok a pohladvka','A','48','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('491000','Vlastn imanie fyzickej osoby','A','49','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('500000','Spotrebovan nkupy','A','50','E','AP_amount:IC_cogs');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('501000','Spotreba materilu','A','50','E','AP_amount:IC_cogs');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('502000','Spotreba energie','A','50','E','AP_amount:IC_cogs');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('503000','Spotreba ostatnch neskladovatel.dodvok','A','50','E','AP_amount:IC_cogs');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('504000','Predan tovar','A','50','E','AP_amount:IC_cogs');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('510000','Sluby','A','51','E','AP_amount:IC_expense');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('511000','Opravy a udrovanie','A','51','E','AP_amount:IC_expense');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('512000','Cestovn','A','51','E','AP_amount:IC_expense');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('513000','Nklady na reprezentciu','A','51','E','AP_amount:IC_expense');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('518000','Ostatn sluby','A','51','E','AP_amount:IC_expense');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('520000','Osobn nklady','A','52','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('521000','Mzdov nklady','A','52','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('522000','Prjmy spolonkov zo zvislej innosti','A','52','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('523000','Odmeny lenom orgnov spolo. a drustva','A','52','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('524000','Zkonn socilne poistenie','A','52','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('525000','Ostatn socilne poistenie','A','52','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('526000','Socilne nklady fyzickej osoby','A','52','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('527000','Zkonn socilne nklady','A','52','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('528000','Ostatn socilne nklady','A','52','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('530000','Dane a poplatky','A','53','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('531000','Cestn da','A','53','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('532000','Da z nehnutelnosti','A','53','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('538000','Ostatn dane a poplatky','A','53','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('540000','In nklady z hospodrskej innosti','A','54','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('541000','Zostat.cena predanho nehmot.a hmot.maj.','A','54','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('542000','Predan material','A','54','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('543000','Dary','A','54','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('544000','Zmluvn pokuty a penle','A','54','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('545000','Ostatn pokuty a penle a roky z omek.','A','54','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('546000','Odpis pohladvky','A','54','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('548000','Ostatn nklady z hospodrskej innosti','A','54','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('551000','Odpisy dlhodobho nehm.a hmotn.majetku','A','55','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('552000','Tvorba zkonnch rezerv','A','55','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('554000','Tvorba ostatnch rezerv','A','55','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('555000','Zutovanie komplex.nkladov bud.obdob','A','55','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('557000','Zutovanie oprvky k opr.polo. k nadob','A','55','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('558000','Tvorba opravnch poloiek','A','55','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('559000','Tvorba ostatnch opravnch poloiek','A','55','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('560000','Finann nklady','A','56','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('561000','Predan cenn papiere a podiely','A','56','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('562000','roky','A','56','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('563000','Kurzov straty','A','56','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('564000','Nklady na precenenie cennch papierov','A','56','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('566000','Nklady na krtkodob finann majetok','A','56','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('567000','Nklady na derivtov opercie','A','56','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('568000','Ostatn finann nklady','A','56','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('569000','Mank a kody na finannom majetku','A','56','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('574000','Tvorba rezerv','A','57','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('579000','Tvorba opravnch poloiek','A','57','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('580000','Mimoriadne nklady','A','58','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('581000','Nklady na zmenu metdy','A','58','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('582000','kody','A','58','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('584000','Tvorba rezerv','A','58','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('588000','Ostatn mimoriadn nklady','A','58','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('589000','Tvorba opravnch poloiek','A','58','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('591000','Da z prjmov z benej inn. - splatn','A','59','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('592000','Da z prjmov z benej inn. - odloen','A','59','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('593000','Da z prjmov z mim.innosti - splatn','A','59','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('594000','Da z prjmov z mim.innosti - odloen','A','59','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('595000','Dodaton odvody dane z prjmov','A','59','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('596000','Prevod podielov na hosp.vsl.spolonkom','A','59','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('597000','Prevod nkladov hospodrskej innosti','A','59','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('598000','Prevod finannch nkladov','A','59','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('600000','Trby za vlastn vykony a tovar','A','60','I','AR_amount:IC_sale:IC_income');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('601000','Trby za vlastn vrobky','A','60','I','AR_amount:IC_sale:IC_income');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('602000','Trby z predaja sluieb','A','60','I','AR_amount:IC_sale:IC_income');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('604000','Trby za tovar','A','60','I','AR_amount:IC_sale');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('610000','Zmena stavu vntroorganizanch zsob','A','61','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('611000','Zmena stavu nedokonenej vroby','A','61','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('612000','Zmena stavu polotovarov','A','61','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('613000','Zmena stavu vrobkov','A','61','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('614000','Zmena stavu zvierat','A','61','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('620000','Aktivcia','A','62','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('621000','Aktivcia materilu a tovaru','A','62','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('622000','Aktivcia vntroorganizanch sluieb','A','62','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('623000','Aktivcia dlhodobho nehmotnho majetku','A','62','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('624000','Aktivcia dlhodobho hmotnho majetku','A','62','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('640000','Ostatn vnosy z hospodrskej innosti','A','64','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('641000','Trby z predaja dlh.nehm.a hmotn.majetku','A','64','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('642000','Trby z predaja materilu','A','64','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('644000','Zmluvn pokuty,penle a roky z omekan.','A','64','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('645000','Ostatn pokuty,penle a roky z omekan.','A','64','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('646000','Vnosy z odpsanch pohladvok','A','64','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('648000','Ostatn vnosy z hospodrskej innosti','A','64','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('652000','Ztovanie zkonnch rezerv','A','65','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('654000','Ztovanie ostatnch rezerv','A','65','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('655000','Ztovanie komplexn.nkladov bud.obdobi','A','65','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('657000','Ztov.oprvok k opr.poloke k nadob.maj','A','65','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('659000','Ztovanie opravnch poloiek','A','65','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('660000','Finann vnosy','A','66','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('661000','Trby z predaja cennch papierov a podie','A','66','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('662000','roky','A','66','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('663000','Kurzov zisky','A','66','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('664000','Vnosy z precenenia cennch papierov','A','66','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('665000','Vnosy z dlhodobho finannho majetku','A','66','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('666000','Vnosy z krtkodob. finannho majetku','A','66','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('667000','Vnosy z derivtovch operci','A','66','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('668000','Ostatn finann vnosy','A','66','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('674000','Ztovanie rezerv','A','67','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('679000','Ztovanie opravnch poloiek','A','67','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('680000','Mimoriadne vnosy','A','68','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('681000','Vnosy zo zmeny metdy','A','68','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('682000','Nhrady kd','A','68','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('684000','Ztovanie rezerv','A','68','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('688000','Ostan mimoriadne vnosy','A','68','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('689000','Ztovanie opravnch poloiek','A','68','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('697000','Prevod vnosov z hospodrskej innosti','A','69','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('698000','Prevod finannch vnosov','A','69','I','AR_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('701000','Zaiaton et svahov','A','70','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('702000','Konen et svahov','A','70','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('710000','et ziskov a strt','A','71','L','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('751000','Prenajat majetok','A','75','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('799000','Ztovac podsvahov et','A','79','A','\N');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('800000','Vntropodnikov nklady','A','80','E','AP_amount');
INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('900000','Vntropodnikov vnosy','A','90','I','AR_amount');
--
INSERT INTO tax (chart_id,rate) VALUES ((select id from chart where accno = '343120'),0.19);
INSERT INTO tax (chart_id,rate) VALUES ((select id from chart where accno = '343220'),0.19);
INSERT INTO tax (chart_id,rate) VALUES ((select id from chart where accno = '343110'),0.10);
INSERT INTO tax (chart_id,rate) VALUES ((select id from chart where accno = '343210'),0.10);
--
INSERT INTO defaults (fldname, fldvalue) VALUES ('inventory_accno_id', (SELECT id FROM chart WHERE accno = '132000'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('income_accno_id', (SELECT id FROM chart WHERE accno = '604000'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('expense_accno_id', (SELECT id FROM chart WHERE accno = '504000'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('fxgain_accno_id', (SELECT id FROM chart WHERE accno = '663000'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('fxloss_accno_id', (SELECT id FROM chart WHERE accno = '563000'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('weightunit', 'kg');
INSERT INTO defaults (fldname, fldvalue) VALUES ('precision', '2');
--
INSERT INTO curr (rn, curr, prec) VALUES (1,'SKK',2);
INSERT INTO curr (rn, curr, prec) VALUES (2,'EUR',2);
INSERT INTO curr (rn, curr, prec) VALUES (3,'CZK',2);

